==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/net/ppp_generic.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0x54f51d69, "skb_queue_head" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0x17a142df, "__copy_from_user" },
	{ 0x350e2f4, "up_read" },
	{ 0x98082893, "__copy_to_user" },
	{ 0x97255bdf, "strlen" },
	{ 0xd3dbfbc4, "_find_first_zero_bit_le" },
	{ 0x594e1317, "__modsi3" },
	{ 0xdff32ed7, "class_device_destroy" },
	{ 0xb3bbf481, "class_device_create" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x36e47222, "remove_wait_queue" },
	{ 0xcc6a24fd, "slhc_init" },
	{ 0x353e3fa5, "__get_user_4" },
	{ 0x8ead0478, "slhc_remember" },
	{ 0xd73fd490, "slhc_uncompress" },
	{ 0x8fa7f112, "alloc_netdev" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x7d11c268, "jiffies" },
	{ 0x53c0767c, "sk_chk_filter" },
	{ 0x5ebb56fb, "down_read" },
	{ 0x211331fa, "__divsi3" },
	{ 0x5beba53, "netif_rx" },
	{ 0xfc3164cf, "__pskb_pull_tail" },
	{ 0xffd5a395, "default_wake_function" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x6f6c40b8, "skb_queue_purge" },
	{ 0x5f754e5a, "memset" },
	{ 0xdd132261, "printk" },
	{ 0xc016be36, "free_netdev" },
	{ 0x8c41cc1f, "register_netdev" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0x2d3f1dd1, "class_create" },
	{ 0x231cf494, "up_write" },
	{ 0xb3fe02b1, "down_write" },
	{ 0x7e71b7cf, "slhc_free" },
	{ 0x5093fa82, "_clear_bit_le" },
	{ 0x9dba41c4, "skb_over_panic" },
	{ 0x9c7d6173, "skb_queue_tail" },
	{ 0x7dceceac, "capable" },
	{ 0x3ff62317, "local_bh_disable" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0xbc10dd97, "__put_user_4" },
	{ 0xfc88a3f6, "__alloc_skb" },
	{ 0x1000e51, "schedule" },
	{ 0xa07b7cbe, "kfree_skb" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x799aca4, "local_bh_enable" },
	{ 0x129bff55, "skb_under_panic" },
	{ 0x39a5ea2, "register_chrdev" },
	{ 0xf4e59dd4, "wake_up_process" },
	{ 0x31ae22a4, "skb_pull_rcsum" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0xb6c70a7d, "__wake_up" },
	{ 0xf6ebc03b, "net_ratelimit" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0xfb7d9c45, "__udivsi3" },
	{ 0xfd8dba4c, "add_wait_queue" },
	{ 0x9808d4d, "sk_run_filter" },
	{ 0x37a0cba, "kfree" },
	{ 0x9d669763, "memcpy" },
	{ 0x98adfde2, "request_module" },
	{ 0xc192d491, "unregister_chrdev" },
	{ 0x5c95a422, "slhc_compress" },
	{ 0x320b40d1, "class_destroy" },
	{ 0xc1ea2bae, "skb_dequeue" },
	{ 0x532d4c7a, "unregister_netdev" },
	{ 0xa4a4021, "__netif_schedule" },
	{ 0x84fdbf6c, "skb_copy_bits" },
	{ 0xf39d9785, "slhc_toss" },
	{ 0xc22616f1, "__init_rwsem" },
	{ 0x313341a3, "_set_bit_le" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=slhc";

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/net/ppp_generic.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0xf8fcd436, "skb_queue_head" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0xfbc74f64, "__copy_from_user" },
	{ 0x350e2f4, "up_read" },
	{ 0x67c2fa54, "__copy_to_user" },
	{ 0x97255bdf, "strlen" },
	{ 0xd3dbfbc4, "_find_first_zero_bit_le" },
	{ 0x594e1317, "__modsi3" },
	{ 0xc2bf2eb7, "class_device_destroy" },
	{ 0xaafc1419, "class_device_create" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x36e47222, "remove_wait_queue" },
	{ 0x24c9e2a0, "slhc_init" },
	{ 0x353e3fa5, "__get_user_4" },
	{ 0x996e260e, "slhc_remember" },
	{ 0x735016d, "slhc_uncompress" },
	{ 0xfbc06c65, "alloc_netdev" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x7d11c268, "jiffies" },
	{ 0x53c0767c, "sk_chk_filter" },
	{ 0x5ebb56fb, "down_read" },
	{ 0x211331fa, "__divsi3" },
	{ 0x9306d09a, "netif_rx" },
	{ 0x5915105c, "__pskb_pull_tail" },
	{ 0xffd5a395, "default_wake_function" },
	{ 0xfa2a45e, "__memzero" },
	{ 0xae94001, "skb_queue_purge" },
	{ 0x5f754e5a, "memset" },
	{ 0xdd132261, "printk" },
	{ 0xd6ebd354, "free_netdev" },
	{ 0xa15cb65b, "register_netdev" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0xa956b923, "class_create" },
	{ 0x231cf494, "up_write" },
	{ 0xb3fe02b1, "down_write" },
	{ 0x4565aaa6, "slhc_free" },
	{ 0x5093fa82, "_clear_bit_le" },
	{ 0xe4e7f697, "skb_over_panic" },
	{ 0x437f4624, "skb_queue_tail" },
	{ 0x7dceceac, "capable" },
	{ 0x3ff62317, "local_bh_disable" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0xbc10dd97, "__put_user_4" },
	{ 0xa0480cc0, "__alloc_skb" },
	{ 0x1000e51, "schedule" },
	{ 0x4c6ea477, "kfree_skb" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x799aca4, "local_bh_enable" },
	{ 0x6fda369f, "skb_under_panic" },
	{ 0xf8af26, "register_chrdev" },
	{ 0x464b4846, "wake_up_process" },
	{ 0x6e784ea2, "skb_pull_rcsum" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0xb6c70a7d, "__wake_up" },
	{ 0xf6ebc03b, "net_ratelimit" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0xfb7d9c45, "__udivsi3" },
	{ 0xfd8dba4c, "add_wait_queue" },
	{ 0x9baf00a1, "sk_run_filter" },
	{ 0x37a0cba, "kfree" },
	{ 0x9d669763, "memcpy" },
	{ 0x98adfde2, "request_module" },
	{ 0xc192d491, "unregister_chrdev" },
	{ 0xab662b1e, "slhc_compress" },
	{ 0xb43dd575, "class_destroy" },
	{ 0x67b4961f, "skb_dequeue" },
	{ 0x64108831, "unregister_netdev" },
	{ 0x1feb2f47, "__netif_schedule" },
	{ 0x9d341f7a, "skb_copy_bits" },
	{ 0x1a75e2c5, "slhc_toss" },
	{ 0xc22616f1, "__init_rwsem" },
	{ 0x313341a3, "_set_bit_le" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=slhc";
